import os
import sys

# import tkinter only if Netgen was configured with USE_GUI=ON
if False:
    import tkinter

_netgen_bin_dir=os.path.realpath(os.path.join(os.path.dirname(__file__),'..','../../Library/bin'))
_netgen_lib_dir=os.path.realpath(os.path.join(os.path.dirname(__file__),'..','../../Library/bin'))

if sys.platform.startswith('win'):
    os.environ['PATH'] += ';'+os.path.realpath(os.path.join(os.path.dirname(__file__),'../../../bin'))

del sys
del os

from . import libngpy



import sys

def Export (mesh, filename):
    """ export Netgen mesh to neutral format """
    
    print ("export mesh in neutral format to file = ", filename)

    f = open (filename, 'w')

    points = mesh.Points()
    print (len(points), file=f)
    for p in points:
        print (p.p[0], p.p[1], p.p[2], file=f)


    volels = mesh.Elements3D();
    print (len(volels), file=f)
    for el in volels:
        print (el.index, end="   ", file=f)
        for p in el.points:
            print (p.nr, end=" ", file=f)
        print(file=f)




